@@ -20,7 +20,6 @@ data = {
         {"name": "--debug", "action": "store_true", "help": "use debug mode"},
         {
             "name": ["-n", "--name"],
-            "default": "cz_conventional_commits",
             "help": "use the given commitizen (default: cz_conventional_commits)",
         },
         {
@@ -90,7 +89,7 @@ data = {
                     {
                         "name": "--tag-format",
                         "help": (
-                            "format used to tag the commmit and read it, "
+                            "the format used to tag the commit and read it, "
                             "use it in existing projects, "
                             "wrap around simple quotes"
                         ),
@@ -116,8 +115,34 @@ data = {
             },
             {
                 "name": ["version"],
-                "help": "get the version of the installed commitizen",
+                "help": (
+                    "get the version of the installed commitizen or the current project"
+                    " (default: installed commitizen)"
+                ),
                 "func": commands.Version,
+                "arguments": [
+                    {
+                        "name": ["-p", "--project"],
+                        "help": "get the version of the current project",
+                        "action": "store_true",
+                        "exclusive_group": "group1",
+                    },
+                    {
+                        "name": ["-c", "--commitizen"],
+                        "help": "get the version of the installed commitizen",
+                        "action": "store_true",
+                        "exclusive_group": "group1",
+                    },
+                    {
+                        "name": ["-v", "--verbose"],
+                        "help": (
+                            "get the version of both the installed commitizen "
+                            "and the current project"
+                        ),
+                        "action": "store_true",
+                        "exclusive_group": "group1",
+                    },
+                ],
             },
             {
                 "name": ["check"],
@@ -135,6 +160,11 @@ data = {
                     }
                 ],
             },
+            {
+                "name": ["init"],
+                "help": "init commitizen configuration",
+                "func": commands.Init,
+            },
         ],
     },
 }
@@ -149,6 +179,7 @@ def main():
         parser.print_help(sys.stderr)
         raise SystemExit()
 
+    # This is for the command required constraint in 2.0
     try:
         args = parser.parse_args()
     except TypeError:
@@ -157,13 +188,15 @@ def main():
 
     if args.name:
         conf.update({"name": args.name})
+    elif not args.name and not conf.path:
+        conf.update({"name": "cz_conventional_commits"})
 
     if args.version:
         warnings.warn(
             "'cz --version' will be deprecated in next major version. "
             "Please use 'cz version' command from your scripts"
         )
-        logging.getLogger("commitizen").setLevel(logging.DEBUG)
+        args.func = commands.Version
 
     if args.debug:
         warnings.warn(
@@ -173,7 +206,9 @@ def main():
         logging.getLogger("commitizen").setLevel(logging.DEBUG)
 
     # TODO: This try block can be removed after command is required in 2.0
+    # Handle the case that argument is given, but no command is provided
     try:
         args.func(conf, vars(args))()
     except AttributeError:
         out.error("Command is required")
+        raise SystemExit()
