@@ -1,16 +1,17 @@
-from typing import Optional
+from typing import Optional, List
 
 import questionary
 from packaging.version import Version
 
 from commitizen import bump, factory, git, out
 from commitizen.config import BaseConfig
-
-NO_COMMITS_FOUND = 3
-NO_VERSION_SPECIFIED = 4
-NO_PATTERN_MAP = 7
-COMMIT_FAILED = 8
-TAG_FAILED = 9
+from commitizen.error_codes import (
+    NO_COMMITS_FOUND,
+    NO_VERSION_SPECIFIED,
+    NO_PATTERN_MAP,
+    COMMIT_FAILED,
+    TAG_FAILED,
+)
 
 
 class Bump:
@@ -19,17 +20,11 @@ class Bump:
     def __init__(self, config: BaseConfig, arguments: dict):
         self.config: BaseConfig = config
         self.arguments: dict = arguments
-        self.parameters: dict = {
+        self.bump_settings: dict = {
             **config.settings,
             **{
                 key: arguments[key]
-                for key in [
-                    "dry_run",
-                    "tag_format",
-                    "prerelease",
-                    "increment",
-                    "bump_message",
-                ]
+                for key in ["tag_format", "prerelease", "increment", "bump_message"]
                 if arguments[key] is not None
             },
         }
@@ -53,7 +48,7 @@ class Bump:
                 is_initial = questionary.confirm("Is this the first tag created?").ask()
         return is_initial
 
-    def find_increment(self, commits: list) -> Optional[str]:
+    def find_increment(self, commits: List[git.GitCommit]) -> Optional[str]:
         bump_pattern = self.cz.bump_pattern
         bump_map = self.cz.bump_map
         if not bump_map or not bump_pattern:
@@ -64,39 +59,45 @@ class Bump:
         )
         return increment
 
-    def __call__(self):
+    def __call__(self):  # noqa: C901
         """Steps executed to bump."""
         try:
-            current_version_instance: Version = Version(self.parameters["version"])
+            current_version_instance: Version = Version(self.bump_settings["version"])
         except TypeError:
-            out.error("[NO_VERSION_SPECIFIED]")
-            out.error("Check if current version is specified in config file, like:")
-            out.error("version = 0.4.3")
+            out.error(
+                "[NO_VERSION_SPECIFIED]\n"
+                "Check if current version is specified in config file, like:\n"
+                "version = 0.4.3\n"
+            )
             raise SystemExit(NO_VERSION_SPECIFIED)
 
         # Initialize values from sources (conf)
         current_version: str = self.config.settings["version"]
-        tag_format: str = self.parameters["tag_format"]
-        bump_commit_message: str = self.parameters["bump_message"]
+
+        tag_format: str = self.bump_settings["tag_format"]
+        bump_commit_message: str = self.bump_settings["bump_message"]
+        version_files: list = self.bump_settings["version_files"]
+
+        dry_run: bool = self.arguments["dry_run"]
+        is_yes: bool = self.arguments["yes"]
+        increment: Optional[str] = self.arguments["increment"]
+        prerelease: str = self.arguments["prerelease"]
+        is_files_only: Optional[bool] = self.arguments["files_only"]
+
         current_tag_version: str = bump.create_tag(
             current_version, tag_format=tag_format
         )
-        files: list = self.parameters["files"]
-        dry_run: bool = self.parameters["dry_run"]
-
-        is_yes: bool = self.arguments["yes"]
-        prerelease: str = self.arguments["prerelease"]
-        increment: Optional[str] = self.arguments["increment"]
-        is_files_only: Optional[bool] = self.arguments["files_only"]
 
         is_initial = self.is_initial_tag(current_tag_version, is_yes)
-        commits = git.get_commits(current_tag_version, from_beginning=is_initial)
+        if is_initial:
+            commits = git.get_commits()
+        else:
+            commits = git.get_commits(current_tag_version)
 
         # No commits, there is no need to create an empty tag.
         # Unless we previously had a prerelease.
         if not commits and not current_version_instance.is_prerelease:
-            out.error("[NO_COMMITS_FOUND]")
-            out.error("No new commits found.")
+            out.error("[NO_COMMITS_FOUND]\n" "No new commits found.")
             raise SystemExit(NO_COMMITS_FOUND)
 
         if increment is None:
@@ -116,15 +117,17 @@ class Bump:
         )
 
         # Report found information
-        out.write(message)
-        out.write(f"tag to create: {new_tag_version}")
-        out.write(f"increment detected: {increment}")
+        out.write(
+            f"message\n"
+            f"tag to create: {new_tag_version}\n"
+            f"increment detected: {increment}\n"
+        )
 
         # Do not perform operations over files or git.
         if dry_run:
             raise SystemExit()
 
-        bump.update_version_in_files(current_version, new_version.public, files)
+        bump.update_version_in_files(current_version, new_version.public, version_files)
         if is_files_only:
             raise SystemExit()
 
