@@ -171,7 +171,7 @@ class ConventionalCommitsCz(BaseCommitizen):
 
     def schema_pattern(self) -> str:
         PATTERN = (
-            r"(build|ci|docs|feat|fix|perf|refactor|style|test|chore|revert)"
+            r"(build|ci|docs|feat|fix|perf|refactor|style|test|chore|revert|bump)"
             r"(\([\w\-]+\))?:\s.*"
         )
         return PATTERN
